# Doxicity 📗

Doxicity is a static site generator that turns markdown files into an HTML website. You can configure it, add data, layouts, partials, plugins, and use Handlebars `{{expressions}}` to do amazing things. There's even a built-in dev server that reloads as you work, so you can preview everything locally before deploying.

Designed in New Hampshire by [Cory LaViska](https://twitter.com/claviska).

---

## Installation

To install Doxicity, run the following command. This assumes you have [Node.js](https://nodejs.org/) installed.

```sh
npm i doxicity
```

## Usage

Here's a quick example to get you started with Doxicity.

```ts
import Doxicity from 'doxicity';

const __dirname = new URL('.', import.meta.url).pathname;

// Configure it
const dox = new Doxicity({
  source: Doxicity.resolve(__dirname),
  destination: Doxicity.resolve(__dirname, '_site'),
  baseUrl: 'https://example.com/'
  // more options here...
});

// Publish it
dox
  .publish()
  .then(result => {
    console.log(
      `Pages published: ${result.pages.length}\n` +
        `Assets copied: ${result.assets.length}\n` +
        `Duration: ${result.timeToPublish}ms\n`
    );
  })
  .catch(err => {
    console.clear();
    console.log(err.message);
  });
```

For more details, [please see the documentation](https://doxicity.com/).
