import Handlebars from 'handlebars';
import urlJoin from 'url-join';
import { createSlug } from '../utilities/strings.js';
export function registerBuiltInHelpers(config) {
    Handlebars.registerHelper('url', (pathname) => {
        if (typeof pathname === 'string') {
            return urlJoin(config.baseUrl, pathname);
        }
        return urlJoin(config.baseUrl);
    });
    Handlebars.registerHelper('asset', (pathname) => {
        if (typeof pathname === 'string') {
            return urlJoin(config.baseUrl, config.assets, pathname);
        }
        return urlJoin(config.baseUrl, config.assets);
    });
    Handlebars.registerHelper('formatDate', (date, options) => {
        const dateToFormat = date === 'now' ? new Date() : new Date(date);
        const args = (options?.hash ?? {});
        return new Intl.DateTimeFormat(args.lang ?? 'en', args).format(dateToFormat);
    });
    Handlebars.registerHelper('formatNumber', (num, options) => {
        const args = (options?.hash ?? {});
        const numberToFormat = parseFloat(String(num));
        return new Intl.NumberFormat(args.lang ?? 'en', args).format(numberToFormat);
    });
    Handlebars.registerHelper('slugify', (string) => {
        return createSlug(string);
    });
}
