export default function (options) {
    const opts = {
        label: 'Copy',
        copiedLabel: 'Copied!',
        ...options
    };
    return {
        name: 'doxicity-copy-code-plugin',
        transform: doc => {
            let hasCodeBlock = false;
            doc.querySelectorAll('pre > code').forEach((code) => {
                const pre = code.closest('pre');
                const button = doc.createElement('button');
                button.setAttribute('type', 'button');
                button.classList.add('copy-code-button');
                button.textContent = opts.label;
                button.setAttribute('data-copied-label', opts.copiedLabel);
                pre.append(button);
                hasCodeBlock = true;
            });
            if (hasCodeBlock) {
                const script = doc.createElement('script');
                script.type = 'module';
                script.textContent = `
          document.addEventListener('click', event => {
            const button = event.target.closest('.copy-code-button');
            const pre = button?.closest('pre');
            const code = pre?.querySelector('code');

            if (button && code) {
              const label = button.textContent;
              const copiedLabel = button.getAttribute('data-copied-label');

              navigator.clipboard.writeText(code.innerText);
              button.textContent = copiedLabel;
              button.classList.add('copy-code-button--copied');

              setTimeout(() => {
                button.textContent = label;
                button.classList.remove('copy-code-button--copied');
              }, 500);
            }
          });
        `;
                doc.body.append(script);
            }
            return doc;
        }
    };
}
